
import java.util.*;
import java.io.*;

/**
 * 
 * TurmaList = Lista(FichaAluno)
 * 
 * Esta  uma m implementao de Turma porque tendo cada aluno
 * um cdigo unvoco Turma deveria ser implementada com sendo
 * uma Tabela de Hashing de Nmero -> FichaAluno, ou seja, uma
 * correspondncia unvoca entre Nmero de Aluno e a sua Ficha.
 * 
 * Porm, o objectivo  estudar e usar o tipo ArrayList<String> 
 * e o novo for() apresentado em JAVA5.
 * 
 * @author F. Mrio Martins - PPIV
 * @version 03/05/2005
 */

public class TurmaList {

   // variveis de instncia

    private ArrayList<FichaAluno> turma; 
		
	/**
	 * Construtor por omisso 
	 */	
	public TurmaList() { 
	    turma = new ArrayList<FichaAluno>();
	}
	
    /**
     * Insere uma coleco de Fichas em turma
     */
	public TurmaList(Collection<FichaAluno> colfichas) { 
	    turma = new ArrayList<FichaAluno>();
	    turma.addAll(colfichas);
	}
	
	// Mtodos de Instncia
	
	/**
	 *  Determina o nmero de alunos da Turma 
	 */	
	public int numAlunos() { return turma.size(); }
	
	/**
	 * Cria uma lista com os nmeros de todos os alunos da turma
	 */	
	public ArrayList<String> codigos() {
	    ArrayList<String> codigos = new ArrayList<String>();
	    for(FichaAluno ficha : turma) {
	        codigos.add(ficha.getNumero());
	    }
	    return codigos;
	 }

   /**
	 *  Insere um novo aluno na turma
	 */
    public void insereAluno(FichaAluno ficha) {		
		turma.add(ficha);
    }

	/**
	 *  Determina a  maiorMdia da turma
	 */	
	public double maiorNotaTurma() {	    
	  double maiorNota = -1.0;	
      double mediaAluno;
	  for(FichaAluno ficha : turma) {
	       mediaAluno = ficha.getMedia();   
	       if(mediaAluno > maiorNota) 
	              maiorNota = mediaAluno;
	  }	 
	  return maiorNota;
    }
		   	
     /**
	 *  Cria a lista com os cdigos dos alunos com nota superior  dada
	 *  como parmetro (ex cdigos dos alunos com nota > 12).
	 */
	 public ArrayList<String> alunosMediaSuperior(double notaRef) {	    
	   ArrayList<String> codigos = new ArrayList<String>();  
	
	   for(FichaAluno ficha : turma) {
	      if( ficha.getMedia() > notaRef ) codigos.add(ficha.getNumero()) ;	         
	   }	 
	   return codigos;
    }
  
   /**
	 * Verifica se um dado aluno cujo cdigo  dado est registado.
	 * Tem que ser usado um Iterator porque o novo for() no permite
	 * incluir condies de paragem da iterao.
	 */	
	public boolean existeAluno(String numAluno) {
	    
	  Iterator it = turma.iterator();
	  FichaAluno ficha;
	  String numero;
	  boolean existe = false;
	  
	  while(it.hasNext() && !existe) {
	      ficha = (FichaAluno) it.next();
	      numero = ficha.getNumero();
	      if(numero.equals(numAluno)) { existe = true; }
	   }
	   return existe;
    }
    
    /**
     * toString()
     */
    public String toString() {
        StringBuilder s = new StringBuilder();
        s.append("-----------  TURMA --------------------\n");
        for(FichaAluno ficha : turma) {
	       s.append(ficha.toString());   
	   }
	   return s.toString();
    }    
}	  
	    


